==> AFF Links Plugin v0.0.zip: AFFaufspuerer/js/lib/header.js <==
// KLEINE FUNKTIONEN
const lambdaID = function(obj) {
  return obj;
}

var FKT_farbeninvertieren = function(col,typ) {
  col = new RGBcolour(col);
  ['r','g','b'].forEach(function(element) {
    col[element] = 255-col[element];
  });
  if (typ === 'rgb') {
    col = col.toRGB();
  } else if ( typ === 'hex') {
    col = col.toHex();
  } else {
    col = col.toHex();
  }
  return col;
};

var FKT_extrahiereAFFdaten = function(affobj,link) {
  var url = link.href;
  var daten = {};
  attribute = affobj.attribute;
  Object.keys(attribute).forEach(function(feld){
    daten[feld] = [];
  });
  daten['node'] = null;
  if(url.getDomain() === affobj.domain) {
    params = url.parseURLparams(true);
    Object.keys(attribute).forEach(function(feld) {if (attribute[feld].suchen) {
        regex = attribute[feld].regex;
        Object.keys(params).forEach(function(key) {
          if(key.match(regex)) {
            daten[feld] = daten[feld].concat(params[key]);
          }
        });
    }});
    daten['node'] = link;
    return({matched: true, daten: daten});
  } else {
    return({matched: false, daten: daten});
  }
}




// HAUPTFUNKTIONEN
var FKT_cssStylesheet = function(url) {
  var animatecss = document.createElement('link');
  animatecss.rel='stylesheet';
  animatecss.href=url;
  document.getElementsByTagName('head')[0].appendChild(animatecss);
}

var FKT_afflinks = {
  herv: {
      pruefen: function(ergebnis) {
          // Prüfe nach, welche Segmente ausgefüllt sind:
          var n = 0;
          ergebnis.affdaten.forEach(function(elementAFF) {
            if (elementAFF.checkbox.includes(false)) {
              elementAFF.herv = false;
            } else {
              elementAFF.herv = true;
              n++;
            }
          });
          // Prüfe nach, ob alle Segmente ausgefüllt sind:
          ergebnis.herv = (n === ergebnis.affdaten.length);
          return ergebnis;
        },
      fokus: function(node,herv) {
          if(herv) {
            node.classList.add(affherv_className);
            if (node.classList.contains(afflinksID.none)) {
              node.style.display = 'block';
            }
          } else {
            node.classList.remove(affherv_className);
            if (node.classList.contains(afflinksID.none)) {
              node.style.display = 'none';
            }
          }
        },
      einzel: function(ergebnis,index,checked) {
          var self = this;
          var node = ergebnis.affdaten[index.segment].daten[index.zeile]['node'];
          if(!ergebnis.auswahlmodus) {
            ergebnis.affdaten.forEach(function(elementAFF,seg) {
              elementAFF.checkbox.forEach(function(bool,zeile,array) {
                var wert = bool && !checked;
                self.fokus(elementAFF.daten[zeile]['node'],wert);
                array[zeile] = wert;
              });
            });
          }
          self.fokus(node,checked);
          ergebnis.affdaten[index.segment].checkbox[index.zeile] = checked;
          if(checked) {
            node.focus();
            node.scrollIntoViewCenter();
          }
          ergebnis = this.pruefen(ergebnis);
          return ergebnis;
        },
      segment: function(ergebnis,index,checked) {
          var self = this;
          if(!ergebnis.auswahlmodus) {
            ergebnis.affdaten.forEach(function(elementAFF,seg) {
              elementAFF.checkbox.forEach(function(bool,zeile,array) {
                var wert = bool && !checked;
                self.fokus(elementAFF.daten[zeile]['node'],wert);
                array[zeile] = wert;
              });
            });
          }
          ergebnis.affdaten[index].checkbox.forEach(function(bool,zeile,array) {
            self.fokus(ergebnis.affdaten[index].daten[zeile]['node'],checked);
            array[zeile] = checked;
          });
          ergebnis = this.pruefen(ergebnis);
          return ergebnis;
        },
      gesamt: function(ergebnis) {
          var self = this;
          var herv = ergebnis.herv;
          var links = {
            block: document.getElementsByClassName(afflinksID.block),
            none: document.getElementsByClassName(afflinksID.none),
          };
          Object.keys(links).forEach(function(key) {
            for(var node of links[key]) {
              self.fokus(node,herv);
            }
          });
          ergebnis.affdaten.forEach(function(elementAFF,seg) {
            elementAFF.herv = herv;
            elementAFF.checkbox.forEach(function(element,zeile,array) {
              self.fokus(elementAFF.daten[zeile]['node'],herv);
              array[zeile] = herv;
            });
          });
          return(ergebnis);
        },
    },
  finden: function(links,ergebnis) {
      var afflinks = ergebnis.affdaten;
      var u = {};
      for(var i=0; i<afflinks.length; i++) {
        for(var j=0; j<links.length; j++) {
          link = links[j];
          scan = FKT_extrahiereAFFdaten(afflinks[i],link);
          if(scan.matched) {
            afflinks[i].daten.push(scan.daten);
            if(link.style.display === 'none') {
              link.classList.add(afflinksID.none);
            } else {
              link.classList.add(afflinksID.block);
            }
            /* ALTER ANSATZ ERHOBEN:
            parent.replaceChild(container,link);
            linkherv.className = afflinksID.herv + ' affherv'; // + ' ' + 'animated infinite bounceIn';
            linkherv.style.backgroundColor =
              FKT_farbeninvertieren(window.getComputedStyle(link,null).backgroundColor,'hex');
            linkherv.style.color =
              FKT_farbeninvertieren(window.getComputedStyle(link,null).color,'hex'); // '#FDFF47'
            */
          }
        }
      }
      var n = 0;
      for(var k=0; k<afflinks.length; k++) {
        n += afflinks[k].daten.length;
      }
      ergebnis.gesucht = true;
      if(n>0) {
        ergebnis.found = true;
      }
      return ergebnis;
    },
  tabelle: function(ergebnis,sender) {
      var tbl = document.createElement('table');
      var nCol = ergebnis.spalten.countUp(lambdaID);
      // Tabellenüberschriften.
      var tr = document.createElement('tr');
      tbl.appendChild(tr);
      tbl.style = 'width=100%;'
      tbl.style.fontSize = 'x-small';
      if(sender === 'popup.js') {
        var th = document.createElement('th');
        var btn = document.createElement('input');
        tr.appendChild(th);
        th.appendChild(btn);
        th.classList.add('table-leer');
        th.classList.add('#tabelle#spalte#checkbox');
        th.style.verticalAlign = 'bottom';
        th.style.textAlign = 'center';
        th.style.fontSize = 'small';
        btn.id = '#tabelle#checkbox#[]';
        btn.classList.add('#tabelle#checkbox');
        btn.type = 'checkbox';
        btn.checked = ergebnis.herv;  // <--- initialisiert
        btn.autofocus = false;
        if(sender === 'popup.js') {
          btn.addEventListener('click',handler.checkbox.gesamt);
        }
      }
      affattribute.forEach(function(element,sp){
        var key = element.tag;
        var th = document.createElement('th');
        tr.appendChild(th);
        th.classList.add('#tabelle#spalte#'+key);
        th.style.verticalAlign = 'bottom';
        th.style.textAlign = 'center';
        th.style.fontSize = 'small';
        th.textContent = element.titelkurz;
        if(!ergebnis.spalten.hasOwnProperty(key)) {
          ergebnis.spalten[key] = true;  // <--- initialisiert
        }
        th.style.display = ergebnis.spalten[key];  // <--- initialisiert
      });
      // Tabellensegmente: pro AFF-Netzwerk.
      ergebnis.affdaten.forEach(function(elementAFF,indexSEGMENT) {
        // Anfang des Segments.
        var n = elementAFF.daten.length;
        if(n>1) { // Segmentheader nur dann zeigen, wenn mindestens 2 Links vorhanden.
          var tr = document.createElement('tr');
          var tdCHECKBOX = document.createElement('td');
          var td = document.createElement('td');
          var btn = document.createElement('input');
          tbl.appendChild(tr);
          tr.appendChild(tdCHECKBOX);
          tr.appendChild(td);
          tdCHECKBOX.appendChild(btn);
          // Checkbox für Segment.
          tdCHECKBOX.classList.add('table-leer');
          tdCHECKBOX.classList.add('#tabelle#spalte#checkbox');
          tdCHECKBOX.style.verticalAlign = 'middle';
          tdCHECKBOX.style.textAlign = 'center';
          btn.id = '#tabelle#checkbox#['+indexSEGMENT+']';
          btn.classList.add('#tabelle#checkbox');
          btn.classList.add('#tabelle#checkbox#segment');
          btn.classList.add('#tabelle#checkbox#segment#'+indexSEGMENT);
          btn.type = 'checkbox';
          btn.checked = elementAFF.herv;  // <--- initialisiert
          btn.autofocus = false;
          if(sender === 'popup.js') {
            btn.addEventListener('click',handler.checkbox.segment(indexSEGMENT));
          }
          // Segmentüberschrift.
          td.classList.add('#tabelle#segment#ueberschrift');
          td.style.textAlign = 'center';
          td.colSpan = nCol;
          td.textContent = elementAFF.netzwerk+': '+n+' Links.';
        }
        // Tabellenzeilen im Segment (eine Zeile pro AFF-Link).
        elementAFF.daten.forEach(function (elementDATEN,indexZEILE) {
          while(elementAFF.checkbox.length <= indexZEILE) {
            elementAFF.checkbox.push(false);  // <--- initialisiert
          }
          var index = {segment: indexSEGMENT, zeile: indexZEILE};
          var tr = document.createElement('tr');
          var tdCHECKBOX = document.createElement('td');
          var btn = document.createElement('input');
          // Tabellenspalten.
          tbl.appendChild(tr);
          if(sender === 'popup.js') {
            tr.appendChild(tdCHECKBOX);
            tdCHECKBOX.appendChild(btn);
            tdCHECKBOX.classList.add('table-leer');
            tdCHECKBOX.classList.add('#tabelle#spalte#checkbox');
            tdCHECKBOX.style.verticalAlign = 'middle';
            tdCHECKBOX.style.textAlign = 'center';
            // Spalte -1: Fokus-Checkboxes.
            btn.id = '#tabelle#checkbox#['+indexSEGMENT+','+indexZEILE+']';
            btn.classList.add('#tabelle#checkbox');
            btn.classList.add('#tabelle#checkbox#segment#'+indexSEGMENT);
            btn.classList.add('#tabelle#checkbox#einzel');
            btn.classList.add('#tabelle#checkbox#einzel#'+indexZEILE);
            btn.type = 'checkbox';
            btn.checked = elementAFF.checkbox[indexZEILE];  // <--- initialisiert
            btn.autofocus = false;
            if(sender === 'popup.js') {
              btn.addEventListener('click',handler.checkbox.einzel(index));
            }
          }
          // Spalten 0+: Alle gemessenen Attribute.
          affattribute.forEach(function(element,sp) {
            key = element.tag;
            var td = document.createElement('td');
            tr.appendChild(td);
            td.classList.add('#tabelle#spalte#'+key);
            td.style.verticalAlign = 'middle';
            td.style.textAlign = 'left';
            td.style.display = ergebnis.spalten[affattribute[sp].tag];  // <--- initialisiert
            if(key === 'netzwerk') {
              td.textContent = elementAFF.netzwerk;
            } else {
              if(elementDATEN.hasOwnProperty(key)) {
                wert = elementDATEN[key];
                if(wert.length > 0) {
                  if (key === 'url') {
                    var a = document.createElement('a');
                    td.appendChild(a);
                    var href = wert[0];
                    var dom = href.getDomain();
                    a.href = href;
                    a.textContent = dom;
                    if(sender === 'popup.js') {
                      a.addEventListener('click', handler.link);
                    }
                  } else {
                    td.textContent = wert[0];
                  }
                } else {
                  td.textContent = 'N/A';
                }
              } else {
                td.textContent = 'N/A';
              }
            }
          });
          // Ende der Spalten.
        });
      });
      // Ende der Tabelle.
      if(sender === 'content.js') {
        var div = document.createElement('div');
        div.appendChild(tbl);
        document.body.appendChild(div);
        tbl.style.display = 'none';
      } else {
        tbl.style.display = 'block';
      }
      return tbl;
    },
};

var FKT_kopieren = {
  selektieren: function(node) {
    var body = document.body;
    var range, sel;
    if (document.createRange && window.getSelection) {
      range = document.createRange();
      sel = window.getSelection();
      sel.removeAllRanges();
      range.selectNodeContents(node);
      sel.addRange(range);
    } else if (body.createTextRange) {
      range = body.createTextRange();
      range.moveToElementText(node);
      range.select();
    }
  },
  deselektieren: function() {
    if (document.selection) {
        document.selection.empty();
    } else if (window.getSelection) {
        window.getSelection().removeAllRanges();
    }
  },
  direkt: function(node) {
    this.selektieren(node);
    document.execCommand('copy');
  },
  bereitstellen: function(node,output) {
    var kopiert = false;
    var status = node.style.display;
    node.style.display = 'block';
    this.selektieren(node);
    try {
      if(document.execCommand('copy')) {
        output.runAttribute(self,'erfolg');
        kopiert = true;
      } else {
        output.runAttribute(self,'misserfolg');
      }
    } catch (err) {
      output.runAttribute(self,'fehler');
    }
    node.style.display = status;
    this.deselektieren();
    return kopiert;
  },
};

==> AFF Links Plugin v1.0.zip: AFFaufspuerer/js/lib/header.js <==
// KLEINE FUNKTIONEN
const lambdaID = function(obj) {
  return obj;
}




// HAUPTFUNKTIONEN
var FKT_cssStylesheet = function(url) {
  var animatecss = document.createElement('link');
  animatecss.rel='stylesheet';
  animatecss.href=url;
  document.getElementsByTagName('head')[0].appendChild(animatecss);
}

var FKT_afflinks = {
  herv: {
      pruefen: function(ergebnis) {
          // Prüfe nach, welche Segmente ausgefüllt sind:
          var n = 0;
          ergebnis.affdaten.forEach(function(elementAFF) {
            if (elementAFF.checkbox.includes(false)) {
              elementAFF.herv = false;
            } else {
              elementAFF.herv = true;
              n++;
            }
          });
          // Prüfe nach, ob alle Segmente ausgefüllt sind:
          ergebnis.herv = (n === ergebnis.affdaten.length);
          return ergebnis;
        },
      fokus: function(node,herv) {
          if(herv) {
            node.classList.add(affherv_className);
            if (node.classList.contains(afflinksID.none)) {
              node.style.display = 'block';
            }
          } else {
            node.classList.remove(affherv_className);
            if (node.classList.contains(afflinksID.none)) {
              node.style.display = 'none';
            }
          }
        },
      einzel: function(ergebnis,index,checked) {
          var self = this;
          var node = ergebnis.affdaten[index.segment].daten[index.zeile]['node'];
          if(!ergebnis.auswahlmodus) {
            ergebnis.affdaten.forEach(function(elementAFF,seg) {
              elementAFF.checkbox.forEach(function(bool,zeile,array) {
                var wert = bool && !checked;
                self.fokus(elementAFF.daten[zeile]['node'],wert);
                array[zeile] = wert;
              });
            });
          }
          self.fokus(node,checked);
          ergebnis.affdaten[index.segment].checkbox[index.zeile] = checked;
          if(checked) {
            node.focus();
            node.scrollIntoViewCenter();
          }
          ergebnis = this.pruefen(ergebnis);
          return ergebnis;
        },
      segment: function(ergebnis,index,checked) {
          var self = this;
          if(!ergebnis.auswahlmodus) {
            ergebnis.affdaten.forEach(function(elementAFF,seg) {
              elementAFF.checkbox.forEach(function(bool,zeile,array) {
                var wert = bool && !checked;
                self.fokus(elementAFF.daten[zeile]['node'],wert);
                array[zeile] = wert;
              });
            });
          }
          ergebnis.affdaten[index].checkbox.forEach(function(bool,zeile,array) {
            self.fokus(ergebnis.affdaten[index].daten[zeile]['node'],checked);
            array[zeile] = checked;
          });
          ergebnis = this.pruefen(ergebnis);
          return ergebnis;
        },
      gesamt: function(ergebnis) {
          var self = this;
          var herv = ergebnis.herv;
          var links = {
            block: document.getElementsByClassName(afflinksID.block),
            none: document.getElementsByClassName(afflinksID.none),
          };
          Object.keys(links).forEach(function(key) {
            for(var node of links[key]) {
              self.fokus(node,herv);
            }
          });
          ergebnis.affdaten.forEach(function(elementAFF,seg) {
            elementAFF.herv = herv;
            elementAFF.checkbox.forEach(function(element,zeile,array) {
              self.fokus(elementAFF.daten[zeile]['node'],herv);
              array[zeile] = herv;
            });
          });
          return(ergebnis);
        },
    },
  scan: function(affobj,link) {
      var url = link.href;
      var daten = {};
      cond = false;
      var idx = 0;
      while(!cond && idx<affobj.attribute.length) {
        if(url.hasDomain(affobj.attribute[idx].domain)) {
          cond = true;
        } else {
          idx++;
        }
      }
      if(cond) {
        attribute = affobj.attribute[idx];
        Object.keys(attribute).forEach(function(feld) {
          if(attribute.hasOwnProperty(feld) && !(attribute[feld] === null)) {
            daten[feld] = [];
          }
        });
        daten['node'] = null;
        params = url.parseURLparams(true);
        Object.keys(attribute).forEach(function(feld) {
          if (!(feld === 'domain') && attribute.hasOwnProperty(feld) && !(attribute[feld] === null)) {
            regex = attribute[feld];
            Object.keys(params).forEach(function(key) {
              if(key.match(regex)) {
                daten[feld] = daten[feld].concat(params[key]);
              }
            });
          }
        });
        daten['node'] = link;
        return({matched: true, daten: daten});
      } else {
        return({matched: false, daten: daten});
      }
    },
  finden: function(links,ergebnis) {
      var afflinks = ergebnis.affdaten;
      var u = {};
      for(var i=0; i<afflinks.length; i++) {
        for(var j=0; j<links.length; j++) {
          var link = links[j];
          var scan = this.scan(afflinks[i],link);
          if(scan.matched) {
            afflinks[i].daten.push(scan.daten);
            if(link.style.display === 'none') {
              link.classList.add(afflinksID.none);
            } else {
              link.classList.add(afflinksID.block);
            }
            /* ALTER ANSATZ ERHOBEN:
            parent.replaceChild(container,link);
            linkherv.className = afflinksID.herv + ' affherv'; // + ' ' + 'animated infinite bounceIn';
            linkherv.style.backgroundColor =
              window.getComputedStyle(link,null).backgroundColor.invertColour('hex');
            linkherv.style.color =
              window.getComputedStyle(link,null).color.invertColour('hex'); // '#FDFF47'
            */
          }
        }
      }
      var n = 0;
      for(var k=0; k<afflinks.length; k++) {
        n += afflinks[k].daten.length;
      }
      ergebnis.gesucht = true;
      if(n>0) {
        ergebnis.found = true;
      }
      return ergebnis;
    },
  tabelle: function(ergebnis,sender) {
      var tbl = document.createElement('table');
      var nCol = ergebnis.spalten.countUp(lambdaID);
      // Tabellenüberschriften.
      var tr = document.createElement('tr');
      tbl.appendChild(tr);
      tbl.style = 'width=100%;'
      tbl.style.fontSize = 'x-small';
      if(sender === 'popup.js') {
        var th = document.createElement('th');
        var btn = document.createElement('input');
        tr.appendChild(th);
        th.appendChild(btn);
        th.classList.add('table-leer');
        th.classList.add('#tabelle#spalte#checkbox');
        th.style.verticalAlign = 'bottom';
        th.style.textAlign = 'center';
        th.style.fontSize = 'small';
        btn.id = '#tabelle#checkbox#[]';
        btn.classList.add('#tabelle#checkbox');
        btn.type = 'checkbox';
        btn.checked = ergebnis.herv;  // <--- initialisiert
        btn.autofocus = false;
        if(sender === 'popup.js') {
          btn.addEventListener('click',handler.checkbox.gesamt);
        }
      }
      affattribute.forEach(function(element,sp){
        var key = element.tag;
        var th = document.createElement('th');
        tr.appendChild(th);
        th.classList.add('#tabelle#spalte#'+key);
        th.style.verticalAlign = 'bottom';
        th.style.textAlign = 'center';
        th.style.fontSize = 'small';
        th.textContent = element.titelkurz;
        if(!ergebnis.spalten.hasOwnProperty(key)) {
          ergebnis.spalten[key] = true;  // <--- initialisiert
        }
        th.style.display = ergebnis.spalten[key];  // <--- initialisiert
      });
      // Tabellensegmente: pro AFF-Netzwerk.
      ergebnis.affdaten.forEach(function(elementAFF,indexSEGMENT) {
        // Anfang des Segments.
        var n = elementAFF.daten.length;
        if(n>1) { // Segmentheader nur dann zeigen, wenn mindestens 2 Links vorhanden.
          var tr = document.createElement('tr');
          var tdCHECKBOX = document.createElement('td');
          var td = document.createElement('td');
          var btn = document.createElement('input');
          tbl.appendChild(tr);
          tr.appendChild(tdCHECKBOX);
          tr.appendChild(td);
          tdCHECKBOX.appendChild(btn);
          // Checkbox für Segment.
          tdCHECKBOX.classList.add('table-leer');
          tdCHECKBOX.classList.add('#tabelle#spalte#checkbox');
          tdCHECKBOX.style.verticalAlign = 'middle';
          tdCHECKBOX.style.textAlign = 'center';
          btn.id = '#tabelle#checkbox#['+indexSEGMENT+']';
          btn.classList.add('#tabelle#checkbox');
          btn.classList.add('#tabelle#checkbox#segment');
          btn.classList.add('#tabelle#checkbox#segment#'+indexSEGMENT);
          btn.type = 'checkbox';
          btn.checked = elementAFF.herv;  // <--- initialisiert
          btn.autofocus = false;
          if(sender === 'popup.js') {
            btn.addEventListener('click',handler.checkbox.segment(indexSEGMENT));
          }
          // Segmentüberschrift.
          td.classList.add('#tabelle#segment#ueberschrift');
          td.style.textAlign = 'center';
          td.colSpan = nCol;
          td.textContent = elementAFF.netzwerk+': '+n+' Links.';
        }
        // Tabellenzeilen im Segment (eine Zeile pro AFF-Link).
        elementAFF.daten.forEach(function (elementDATEN,indexZEILE) {
          while(elementAFF.checkbox.length <= indexZEILE) {
            elementAFF.checkbox.push(false);  // <--- initialisiert
          }
          var index = {segment: indexSEGMENT, zeile: indexZEILE};
          var tr = document.createElement('tr');
          var tdCHECKBOX = document.createElement('td');
          var btn = document.createElement('input');
          // Tabellenspalten.
          tbl.appendChild(tr);
          if(sender === 'popup.js') {
            tr.appendChild(tdCHECKBOX);
            tdCHECKBOX.appendChild(btn);
            tdCHECKBOX.classList.add('table-leer');
            tdCHECKBOX.classList.add('#tabelle#spalte#checkbox');
            tdCHECKBOX.style.verticalAlign = 'middle';
            tdCHECKBOX.style.textAlign = 'center';
            // Spalte -1: Fokus-Checkboxes.
            btn.id = '#tabelle#checkbox#['+indexSEGMENT+','+indexZEILE+']';
            btn.classList.add('#tabelle#checkbox');
            btn.classList.add('#tabelle#checkbox#segment#'+indexSEGMENT);
            btn.classList.add('#tabelle#checkbox#einzel');
            btn.classList.add('#tabelle#checkbox#einzel#'+indexZEILE);
            btn.type = 'checkbox';
            btn.checked = elementAFF.checkbox[indexZEILE];  // <--- initialisiert
            btn.autofocus = false;
            if(sender === 'popup.js') {
              btn.addEventListener('click',handler.checkbox.einzel(index));
            }
          }
          // Spalten 0+: Alle gemessenen Attribute.
          affattribute.forEach(function(element,sp) {
            key = element.tag;
            var td = document.createElement('td');
            tr.appendChild(td);
            td.classList.add('#tabelle#spalte#'+key);
            td.style.verticalAlign = 'middle';
            td.style.textAlign = 'left';
            td.style.display = ergebnis.spalten[affattribute[sp].tag];  // <--- initialisiert
            if(key === 'netzwerk') {
              td.textContent = elementAFF.netzwerk;
            } else if(elementDATEN.hasOwnProperty(key)) {
                wert = elementDATEN[key];
                if(wert.length > 0) {
                  if (key === 'url') {
                    var a = document.createElement('a');
                    td.appendChild(a);
                    var href = wert[0];
                    var dom = href.getDomain();
                    a.href = href;
                    a.textContent = dom;
                    if(sender === 'popup.js') {
                      a.addEventListener('click', handler.link);
                    }
                  } else {
                    td.textContent = wert[0];
                  }
                } else {
                  td.textContent = affTblLeer.nichtgefunden;
                }
            } else {
              td.textContent = affTblLeer.nichtgesucht;
            }
          });
          // Ende der Spalten.
        });
      });
      // Ende der Tabelle.
      if(sender === 'content.js') {
        var div = document.createElement('div');
        div.appendChild(tbl);
        document.body.appendChild(div);
        tbl.style.display = 'none';
      } else {
        tbl.style.display = 'block';
      }
      return tbl;
    },
};

var FKT_kopieren = {
  selektieren: function(node) {
    var body = document.body;
    var range, sel;
    if (document.createRange && window.getSelection) {
      range = document.createRange();
      sel = window.getSelection();
      sel.removeAllRanges();
      range.selectNodeContents(node);
      sel.addRange(range);
    } else if (body.createTextRange) {
      range = body.createTextRange();
      range.moveToElementText(node);
      range.select();
    }
  },
  deselektieren: function() {
    if (document.selection) {
        document.selection.empty();
    } else if (window.getSelection) {
        window.getSelection().removeAllRanges();
    }
  },
  direkt: function(node) {
    this.selektieren(node);
    document.execCommand('copy');
  },
  bereitstellen: function(node,output) {
    var kopiert = false;
    var status = node.style.display;
    node.style.display = 'block';
    this.selektieren(node);
    try {
      if(document.execCommand('copy')) {
        output.runAttribute(self,'erfolg');
        kopiert = true;
      } else {
        output.runAttribute(self,'misserfolg');
      }
    } catch (err) {
      output.runAttribute(self,'fehler');
    }
    node.style.display = status;
    this.deselektieren();
    return kopiert;
  },
};
